@@ -24,8 +24,8 @@ def get_data(xml):
     success_xml_entry = _get_xml_field(xml, "Success")
     try:
         data = success_xml_entry['Data']
-    except KeyError:
-        data = None
+    except (KeyError, TypeError):
+        data = {}
     return data
 
 
@@ -52,4 +52,4 @@ def _get_xml_field(xml, field, data_field=None):
         except KeyError:
             return None
     except xmltodict.expat.ExpatError:
-        pass
+        return {}
