@@ -71,7 +71,7 @@ class HttpClient(object):
                                             timeout=5,
                                             verify=False)
             if 400 < response.status_code < 500:
-                raise KempTechApiException(code=response.status_code)
+                raise KempTechApiException(msg=response.text)
             else:
                 response.raise_for_status()
         except exceptions.ConnectTimeout:
